==> telegram_client-0.5.16.tar.gz: template/telegram_userbot_tdlib_template/bin/telegram_userbot_tdlib_template.dart <==
// ignore_for_file: non_constant_identifier_names, unnecessary_brace_in_string_interps, unused_import

import "dart:io";

import "package:galaxeus_lib/galaxeus_lib.dart";
import "package:telegram_userbot_tdlib_template/telegram_userbot_tdlib_template.dart";
import "package:telegram_client/telegram_client.dart";
import "package:path/path.dart" as path;

import "package:mason_logger/mason_logger.dart";

String get getFormatLibrary {
  if (Platform.isAndroid || Platform.isLinux) {
    return "so";
  } else if (Platform.isIOS || Platform.isMacOS) {
    return "dylib";
  } else {
    return "dll";
  }
}

String ask({
  required String question,
}) {
  while (true) {
    stdout.write(question);
    String? res = stdin.readLineSync();
    if (res != null && res.isNotEmpty) {
      return res;
    }
  }
}

void main(List<String> arguments) async {
  Directory directory_current = Directory.current;
  Directory telegram_directory =
      Directory(path.join(directory_current.path, "tg_database"));

  /// telegram database
  int api_id = () {
    if ((int.tryParse(Platform.environment["api_id"] ?? "0") ?? 0) > 0) {
      return (int.tryParse(Platform.environment["api_id"] ?? "0") ?? 0);
    }

    int api_id = int.tryParse(logger.prompt(
            "\ntelegram api id https://my.telegram.org/\nApi Id : ",
            defaultValue: "94575")) ??
        0;

    while (true) {
      if (api_id > 0) {
        break;
      } else {
        api_id = int.tryParse(logger.prompt(
                "\nFormat Salah\ntelegram api id https://my.telegram.org/\nApi Id : ",
                defaultValue: "94575")) ??
            0;
      }
    }

    return api_id;
  }(); // telegram api id https://my.telegram.org/
  String api_hash = () {
    if ((Platform.environment["api_hash"] ?? "").isNotEmpty) {
      return (Platform.environment["api_hash"] ?? "");
    }

    String prompt_data = (logger.prompt(
        "\ntelegram api Hash https://my.telegram.org/\nApi Hash : ",
        defaultValue: "a3406de8d171bb422bb6ddf3bbd800e2"));

    while (true) {
      if (prompt_data.isNotEmpty) {
        break;
      } else {
        prompt_data = (logger.prompt(
            "\ntelegram api Hash https://my.telegram.org/\nApi Hash : ",
            defaultValue: "a3406de8d171bb422bb6ddf3bbd800e2"));
      }
    }
    return prompt_data;
  }(); // telegram api hash https://my.telegram.org/
  int owner_chat_id = () {
    if ((int.tryParse(Platform.environment["owner_chat_id"] ?? "0") ?? 0) > 0) {
      return (int.tryParse(Platform.environment["owner_chat_id"] ?? "0") ?? 0);
    }
    int prompt_data = int.tryParse(logger.prompt(
            "\nBuka Telegram @azkadevbot lalu typing /getMe\nOwner Chat Id : ",
            defaultValue: 1)) ??
        0;

    while (true) {
      if (prompt_data > 0) {
        break;
      } else {
        prompt_data = int.tryParse(logger.prompt(
                "\nFormat Salah\nBuka Telegram @azkadevbot lalu typing /getMe\nOwner Chat Id : ",
                defaultValue: 1)) ??
            0;
      }
    }

    return prompt_data;
  }(); // owner telegram chat id

  List<FileSystemEntity> accounts = telegram_directory
      .listSync()
      .map((e) {
        if (RegExp("^(account_)", caseSensitive: false)
            .hasMatch(path.basename(e.path))) {
          return e;
        }
        return null;
      })
      .whereType<FileSystemEntity>()
      .toList();

  List<String> account_names = [
    "Create New",
    ...accounts.map((e) => path.basename(e.path)).toList(),
  ];

  String choose_client = logger.chooseOne(
    "\nPilih Client",
    choices: account_names,
    display: (choice) {
      return path
          .basename(choice)
          .replaceAll(RegExp(r"^(account_)", caseSensitive: false), "");
    },
  );

  if (choose_client == account_names.first) {
    choose_client = logger.prompt("New Client Name? : ");
    while (true) {
      if (Directory(path.join(telegram_directory.path, choose_client))
          .existsSync()) {
        choose_client = logger.prompt(
            "Client: ${choose_client} Sudah ada tolong bikin yang baru ya\n\nNew Client Name? : ");
      } else {
        break;
      }
    }
    choose_client = "account_${choose_client}";
  }

  List<String> name_clients = [
    choose_client,
  ];

  Tdlib tg = Tdlib(
    pathTdl: "libtdjson.${getFormatLibrary}",
    clientOption: {
      'api_id': api_id,
      'api_hash': api_hash,
    },
    invokeTimeOut: Duration(minutes: 10),
    delayInvoke: Duration(milliseconds: 10),
  );

  TelegramUserbotTdlibTemplate telegram_userbot_tdlib_template =
      TelegramUserbotTdlibTemplate(
    tg: tg,
    telegram_directory: telegram_directory,
    owner_chat_id: owner_chat_id,
    name_clients: name_clients,
  );

  try {
    var res = await tg.invoke("getMe",
        parameters: {}, clientId: 10, invokeTimeOut: Duration(seconds: 10));
    print(res);
  } catch (e) {
    print(e);
  }
  await telegram_userbot_tdlib_template.userbot(
    onAuthState: (int client_id, String name_client,
        AuthorizationStateType authorizationStateType) async {
      ///
      if (authorizationStateType == AuthorizationStateType.phone_number) {
        String phone_number = ask(question: "Phone Number: ");
        phone_number = phone_number.replaceAll(
            RegExp(r"(\+|([ ]+))", caseSensitive: false), "");
        await tg.request(
          "setAuthenticationPhoneNumber",
          parameters: {
            "phone_number": phone_number,
          },
          clientId: client_id, // add this if your project more one client
        );
      }

      if (authorizationStateType == AuthorizationStateType.code) {
        String code = ask(question: "Code: ");
        await tg.request(
          "checkAuthenticationCode",
          parameters: {
            "code": code,
          },
          clientId: client_id, // add this if your project more one client
        );
      }
      if (authorizationStateType == AuthorizationStateType.password) {
        String password = ask(question: "Password: ");
        await tg.request(
          "checkAuthenticationPassword",
          parameters: {
            "password": password,
          },
          clientId: client_id, // add this if your project more one client
        );
      }
    },
  );
}

==> telegram_client-0.5.56.tar.gz: template/telegram_userbot_tdlib_template/bin/telegram_userbot_tdlib_template.dart <==
// ignore_for_file: non_constant_identifier_names, camel_case_extensions, camel_case_extensions unnecessary_brace_in_string_interps, unused_import

import "dart:io";

import "package:galaxeus_lib/galaxeus_lib.dart";
import "package:telegram_userbot_tdlib_template/telegram_userbot_tdlib_template.dart";
import "package:telegram_client/telegram_client.dart";
import "package:path/path.dart" as path;

import "package:mason_logger/mason_logger.dart";

String get getFormatLibrary {
  if (Platform.isAndroid || Platform.isLinux) {
    return "so";
  } else if (Platform.isIOS || Platform.isMacOS) {
    return "dylib";
  } else {
    return "dll";
  }
}

String ask({
  required String question,
}) {
  while (true) {
    stdout.write(question);
    String? res = stdin.readLineSync();
    if (res != null && res.isNotEmpty) {
      return res;
    }
  }
}

void main(List<String> arguments) async {
  Directory directory_current = Directory.current;
  Directory telegram_directory =
      Directory(path.join(directory_current.path, "tg_database"));

  /// telegram database
  int api_id = () {
    if ((int.tryParse(Platform.environment["api_id"] ?? "0") ?? 0) > 0) {
      return (int.tryParse(Platform.environment["api_id"] ?? "0") ?? 0);
    }

    int api_id = int.tryParse(logger.prompt(
            "\ntelegram api id https://my.telegram.org/\nApi Id : ",
            defaultValue: "94575")) ??
        0;

    while (true) {
      if (api_id > 0) {
        break;
      } else {
        api_id = int.tryParse(logger.prompt(
                "\nFormat Salah\ntelegram api id https://my.telegram.org/\nApi Id : ",
                defaultValue: "94575")) ??
            0;
      }
    }

    return api_id;
  }(); // telegram api id https://my.telegram.org/
  String api_hash = () {
    if ((Platform.environment["api_hash"] ?? "").isNotEmpty) {
      return (Platform.environment["api_hash"] ?? "");
    }

    String prompt_data = (logger.prompt(
        "\ntelegram api Hash https://my.telegram.org/\nApi Hash : ",
        defaultValue: "a3406de8d171bb422bb6ddf3bbd800e2"));

    while (true) {
      if (prompt_data.isNotEmpty) {
        break;
      } else {
        prompt_data = (logger.prompt(
            "\ntelegram api Hash https://my.telegram.org/\nApi Hash : ",
            defaultValue: "a3406de8d171bb422bb6ddf3bbd800e2"));
      }
    }
    return prompt_data;
  }(); // telegram api hash https://my.telegram.org/
  int owner_chat_id = () {
    if ((int.tryParse(Platform.environment["owner_chat_id"] ?? "0") ?? 0) > 0) {
      return (int.tryParse(Platform.environment["owner_chat_id"] ?? "0") ?? 0);
    }
    int prompt_data = int.tryParse(logger.prompt(
            "\nBuka Telegram @azkadevbot lalu typing /getMe\nOwner Chat Id : ",
            defaultValue: 1)) ??
        0;

    while (true) {
      if (prompt_data > 0) {
        break;
      } else {
        prompt_data = int.tryParse(logger.prompt(
                "\nFormat Salah\nBuka Telegram @azkadevbot lalu typing /getMe\nOwner Chat Id : ",
                defaultValue: 1)) ??
            0;
      }
    }

    return prompt_data;
  }(); // owner telegram chat id

  List<FileSystemEntity> accounts = telegram_directory
      .listSync()
      .map((e) {
        if (RegExp("^(account_)", caseSensitive: false)
            .hasMatch(path.basename(e.path))) {
          return e;
        }
        return null;
      })
      .whereType<FileSystemEntity>()
      .toList();

  List<String> account_names = [
    "Create New",
    ...accounts.map((e) => path.basename(e.path)).toList(),
  ];

  String choose_client = logger.chooseOne(
    "\nPilih Client",
    choices: account_names,
    display: (choice) {
      return path
          .basename(choice)
          .replaceAll(RegExp(r"^(account_)", caseSensitive: false), "");
    },
  );

  if (choose_client == account_names.first) {
    choose_client = logger.prompt("New Client Name? : ");
    while (true) {
      if (Directory(path.join(telegram_directory.path, choose_client))
          .existsSync()) {
        choose_client = logger.prompt(
            "Client: $choose_client Sudah ada tolong bikin yang baru ya\n\nNew Client Name? : ");
      } else {
        break;
      }
    }
    choose_client = "account_$choose_client";
  }

  List<String> name_clients = [
    choose_client,
  ];

  Tdlib tg = Tdlib(
    pathTdl: "libtdjson.$getFormatLibrary",
    clientOption: {
      'api_id': api_id,
      'api_hash': api_hash,
    },
    invokeTimeOut: Duration(minutes: 10),
    delayInvoke: Duration(milliseconds: 10),
  );

  TelegramUserbotTdlibTemplate telegram_userbot_tdlib_template =
      TelegramUserbotTdlibTemplate(
    tg: tg,
    telegram_directory: telegram_directory,
    owner_chat_id: owner_chat_id,
    name_clients: name_clients,
  );

  try {
    var res = await tg.invoke("getMe",
        parameters: {}, clientId: 10, invokeTimeOut: Duration(seconds: 10));
    print(res);
  } catch (e) {
    print(e);
  }
  await telegram_userbot_tdlib_template.userbot(
    onAuthState: (int client_id, String name_client,
        AuthorizationStateType authorizationStateType) async {
      ///
      if (authorizationStateType == AuthorizationStateType.phone_number) {
        String phone_number = ask(question: "Phone Number: ");
        phone_number = phone_number.replaceAll(
            RegExp(r"(\+|([ ]+))", caseSensitive: false), "");
        await tg.request(
          "setAuthenticationPhoneNumber",
          parameters: {
            "phone_number": phone_number,
          },
          clientId: client_id, // add this if your project more one client
        );
      }

      if (authorizationStateType == AuthorizationStateType.code) {
        String code = ask(question: "Code: ");
        await tg.request(
          "checkAuthenticationCode",
          parameters: {
            "code": code,
          },
          clientId: client_id, // add this if your project more one client
        );
      }
      if (authorizationStateType == AuthorizationStateType.password) {
        String password = ask(question: "Password: ");
        await tg.request(
          "checkAuthenticationPassword",
          parameters: {
            "password": password,
          },
          clientId: client_id, // add this if your project more one client
        );
      }
    },
  );
}
